==> haskell-hspec-expectations-0.8.2-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-expectations
version: 0.8.2
id: hspec-expectations-0.8.2-9JgK0FgjaFj1ZSi2zSJcvx
key: hspec-expectations-0.8.2-9JgK0FgjaFj1ZSi2zSJcvx
license: MIT
copyright: (c) 2011-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-expectations#readme
synopsis: Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>
category: Testing
abi: c8d8c2a6481b4436c64f9477e7020a78
exposed: True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
hidden-modules: Test.Hspec.Expectations.Matcher
                Paths_hspec_expectations
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-expectations-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-expectations-0.8.2
hs-libraries: HShspec-expectations-0.8.2-9JgK0FgjaFj1ZSi2zSJcvx
depends:
    HUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c base-4.12.0.0
    call-stack-0.2.0-BFXF1vLNVFn5iwCyADehK4
haddock-interfaces: /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock
haddock-html: /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-0.8.2-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-expectations
version: 0.8.2
id: hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
key: hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
license: MIT
copyright: (c) 2011-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-expectations#readme
synopsis: Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>
category: Testing
abi: 0c9fdcbe57813a6cf7e18902d1b13da2
exposed: True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
hidden-modules: Test.Hspec.Expectations.Matcher
                Paths_hspec_expectations
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-expectations-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-expectations-0.8.2
hs-libraries: HShspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
depends:
    HUnit-1.6.0.0-JbqplLUCHWj8gC9WuQWK9 base-4.12.0.0
    call-stack-0.2.0-7kE9ck8b3cWExm7jAiSNAI
haddock-interfaces: /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock
haddock-html: /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
